/*
   ui/bitmap.h
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#include "auxiliary/functions.h"
#include "ui/bitmap.h"
#include "ui/paint.h"
#include "sys/sys.h"

namespace ui
{

Bitmap::Bitmap(Widget *parent, const char *texture) : Widget(parent)
{
	set_border(false);
	set_background(true);
	set_label("bitmap");
	
	set_texture(texture);
}

Bitmap::~Bitmap()
{}

void Bitmap::print(const size_t indent) const
{
	std::string marker("");
	con_print << aux::pad_left(marker, indent*2) << label() << " \"" << texture() << "\"" << std::endl;
}

void Bitmap::set_texture(const std::string & texture)
{
	bitmap_texture.assign(texture);
}

void Bitmap::set_texture(const char *texture)
{
	if (texture)
		bitmap_texture.assign(texture);
	else
		bitmap_texture.clear();
}

void Bitmap::set_color(const math::Color & color)
{
	bitmap_color.assign(color);
}

void Bitmap::draw_background()
{
	if (bitmap_texture.size()) {
		paint::color(bitmap_color);
		paint::bitmap(global_location(), size(), bitmap_texture);
	}
}

}

